package fr.itsonus.bousoleplussbackend.controllers;

import fr.itsonus.bousoleplussbackend.payload.request.NotifyPasswordResetRequest;
import fr.itsonus.bousoleplussbackend.payload.request.ResetPasswordRequest;
import fr.itsonus.bousoleplussbackend.payload.request.UpdateAccountRequest;
import fr.itsonus.bousoleplussbackend.payload.request.UpdatePasswordRequest;
import fr.itsonus.bousoleplussbackend.usecase.UserPasswordResetUseCase;
import fr.itsonus.bousoleplussbackend.usecase.UserUpdateUseCase;
import jakarta.validation.Valid;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;


@RestController
@RequestMapping("/account")
@AllArgsConstructor
public class AccountController {

    private final UserUpdateUseCase userUpdateUseCase;
    private final UserPasswordResetUseCase userPasswordResetUseCase;

    @PutMapping
    public void update(@Valid @RequestBody UpdateAccountRequest request) {
        userUpdateUseCase.update(request.username(), request.email());
    }

    @PutMapping("password")
    public void update(@Valid @RequestBody UpdatePasswordRequest request) {
        userUpdateUseCase.updatePassword(request.currentPassword(), request.newPassword(), request.confirmationPassword());
    }

    @PostMapping("password/notify-reset-request")
    public void notifyForPasswordReset(@Valid @RequestBody NotifyPasswordResetRequest request) {
        userPasswordResetUseCase.notifyForPasswordReset(request.email());
    }

    @PostMapping("password/reset")
    public void resetPassword(@Valid @RequestBody ResetPasswordRequest request) {
        userPasswordResetUseCase.resetPassword(request.token(), request.email(), request.newPassword(), request.confirmationPassword());
    }
}
