package fr.itsonus.bousoleplussbackend.infrastructure.postgres.models;

import fr.itsonus.bousoleplussbackend.domain.quiz.model.Question;
import jakarta.persistence.Column;
import jakarta.persistence.Entity;
import jakarta.persistence.GeneratedValue;
import jakarta.persistence.Id;
import jakarta.persistence.JoinColumn;
import jakarta.persistence.ManyToOne;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.Size;
import lombok.Getter;
import lombok.RequiredArgsConstructor;
import lombok.Setter;
import lombok.ToString;
import org.hibernate.Hibernate;

import java.util.Objects;

@Getter
@Setter
@ToString
@RequiredArgsConstructor
@Entity(name = "question")
public class PostgresQuestionDto {

    @Id
    @GeneratedValue
    private Long id;

    @ManyToOne
    @JoinColumn(name = "axe_id")
    @ToString.Exclude
    private PostgresAxeDto axe;

    @NotBlank
    @Size(max = 200)
    @Column(nullable = false)
    private String label;

    @Size(max = 500)
    private String description;

    @ManyToOne
    @JoinColumn(name = "bundle_id")
    @ToString.Exclude
    private PostgresBundleDto bundle;

    @Column(nullable = false)
    private Integer index;

    public Question toQuestion() {
        return Question.builder()
                .id(id)
                .axeId(axe.getId())
                .label(label)
                .index(index)
                .description(description)
                .build();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || Hibernate.getClass(this) != Hibernate.getClass(o)) return false;
        var question = (PostgresQuestionDto) o;
        return id != null && Objects.equals(id, question.id);
    }

    @Override
    public int hashCode() {
        return getClass().hashCode();
    }
}
